/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Johannes Maywald, Girija Borker
---------------------------------------------------------------------------
Do file: 16_dowry_income_analysis.do

Analyses the relationship of dowries and family wealth.
=========================================================================*/

clear all
set more off


// NOTE: v1 = all possible information including negative svy and average with only 1 measure available

*** Generate/Load dataset ***
*---------------------------------------------------------------------------------------------------------------------------------------------------------------

*do "code/coding/Dowry_Income.do" // creates the dataset below

use "${raw}/2017-12-07-Dowry_income.dta", clear


	drop if questionnaire=="FPR" 	// FPR: divorced/widowed women might face an entirely different situation.


	merge m:1 p_code v_code nirt_no caste using "${raw}/Predicted1871IncomeForSICHS.dta" , gen(_merge_pred1871)

	tab 	_merge_pred1871
	drop if _merge_pred1871==2 	// using only
	drop 	_merge_pred1871

	sum 	predicted1871income




*** Variables ***
*---------------------------------------------------------------------------------------------------------------------------------------------------------------


	*** Female Dummy ***
	gen 	female=1 if person=="daughter"
	replace female=0 if person=="son"


	label variable female "Female"


	*** Married Sample ***
	gen 	married=1 	if person=="daughter" | person=="son"
	sum married 	// 1032


	
	***************************************
	*** Dowry stats in TABLE 1 of paper ***
	***************************************
	sum dowry_calc , detail

	bysort person: sum dowry_calc

	gen 			log_dowry = log(dowry_calc)
	label variable 	log_dowry "Log dowry"


	*** Survey Income ***
	sum land_profits 	, detail
	sum labour_income 	, detail
	sum hh_income 		, detail

	rename hh_income 			income_svy

	// replace income_svy=. 	if income_svy<0 	// drop negative incomes




	*** Census Income ***
	sum landprofits_yr 	, detail
	sum workincome  	, detail
	sum householdincome , detail

	rename householdincome 		income_cns




	*** Average of Survey and Census Income ***
	corr income_svy  income_cns 	// corr = 0.40
	reg  income_svy  income_cns		// beta = 0.63


	egen 			income_avg = rowmean(income_svy income_cns) // would ignore missings and use only 1 value 
	label variable 	income_avg "Monthly household income in thousand Rupees"

	// Note: Don't use only 1 measure when the other is not available, since we try to purge measurement error with this average
	// replace income_avg = . 	if missing(income_svy)
	// replace income_avg = . 	if missing(income_cns)



	*** Per Capita Family Wealth ***
	gen 			pc_income_avg = income_avg / familysize
	label variable 	pc_income_avg "Income per capita"



	*** Dowry in terms of Annual Income ***
	gen 				dowry_frac_income_avg = dowry_calc/(income_avg*12)
	label variable 		dowry_frac_income_avg "Dowry in terms of annual household income"
	bysort person: sum 	dowry_frac_income_avg



	gen 				dowry_frac_income_svy = dowry_calc/(income_svy*12)
	label variable 		dowry_frac_income_svy "Dowry in terms of annual household income"
	bysort person: sum 	dowry_frac_income_svy




	*** Predicted Survey Income based on Census ***
	reg 	income_svy 		income_cns // female i.caste
	predict income_svy_hat

	gen 			pc_income_svy_hat= income_svy_hat / familysize
	label variable 	pc_income_svy_hat "Income (pred) per capita"




	*** Predicted Income based on 1871 Census ***
	gen income_1871 	= predicted1871income
	gen pc_income_1871 	= income_1871 / familysize



	local WealthVars "income_cns income_svy    income_avg  pc_income_avg   income_svy_hat pc_income_svy_hat   income_1871 pc_income_1871"


	foreach wealth_measure of local WealthVars {
 
		*** ALL households in the caste ***
		local group_vars "caste" 		// e.g. by caste and side of the market

		bysort `group_vars': egen 	wealth_rk 	 = 	rank(`wealth_measure') 	// rank from 1 lowest, to _n   highest
		replace 					wealth_rk 	 = 	wealth_rk-1 	// shift: rank from 0 lowest, to _n-1 highest
		
		bysort `group_vars': egen 	wealth_rkmax = max(wealth_rk)

		gen 			rel_`wealth_measure' = wealth_rk/wealth_rkmax // where 1 is wealthiest and 0 is poorest
		*drop if missing(rel_caste_wealth) // (186 missing value generated) alone in his caste - division by zero
		label variable 	rel_`wealth_measure' "Rank in caste wealth distribution"

		drop wealth_rk wealth_rkmax



		*** ONLY households with married children ***
		local group_vars "caste married" 

		bysort `group_vars': egen 	wealth_rk 	 = 	rank(`wealth_measure') 	// rank from 1 lowest, to _n   highest
		replace 					wealth_rk 	 = 	wealth_rk-1 	// shift: rank from 0 lowest, to _n-1 highest
		
		bysort `group_vars': egen 	wealth_rkmax = max(wealth_rk)

		gen 			rel_`wealth_measure'_m = wealth_rk/wealth_rkmax // where 1 is wealthiest and 0 is poorest
		*drop if missing(rel_caste_wealth_m) // (6 missing value generated) alone in his caste - division by zero
		label variable 	rel_`wealth_measure'_m "Rank in caste wealth distribution (married)"

		drop wealth_rk wealth_rkmax

		replace 		rel_`wealth_measure'_m =. 	if married!=1 	// this relative wealth only for married


	}






*** Regressions ***
*---------------------------------------------------------------------------------------------------------------------------------------------------------------


	cap drop 		wealth_measure 	// the regressor changes across coloumns, but should be on the same row!
	gen 			wealth_measure = .
	label variable 	wealth_measure "Wealth"


	sum dowry_calc 	if !missing(caste) 
	scalar dowry_mean = r(mean)


	*** Specifications ***

	* per capita wealth (average) * 

	replace wealth_measure = rel_pc_income_avg

	eststo relpcavg_f_c , title("Rank in caste wealth distribution (avg.pc)"): 	reg dowry_calc 		wealth_measure 		female i.caste  	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"
	estadd local  female_d 		"Yes"


	eststo relpcavg_f_c_pc , title("Rank in caste wealth distribution (avg.pc)"): 	reg dowry_calc 		wealth_measure pc_income_avg 	female i.caste  	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"


	* per capita wealth (average) * 

	replace wealth_measure = rel_pc_income_avg_m

	eststo relpcavgm_f_c , title("Rank in caste wealth distribution (avg.pc) (married)"): 	reg dowry_calc 		wealth_measure 		female i.caste 	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"


	eststo relpcavgm_f_c_pc , title("Rank in caste wealth distribution (avg.pc) (married)"): 	reg dowry_calc 		wealth_measure pc_income_avg 	female i.caste 	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"


	* relative income average * 

	replace wealth_measure = rel_income_avg

	eststo relavg_f_c , title("Rank in caste wealth distribution (avg)"): 	reg dowry_calc 		wealth_measure 		female i.caste  	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"
	estadd local  female_d 		"Yes"

	replace wealth_measure = rel_income_avg_m	

	eststo relavgm_f_c , title("Rank in caste wealth distribution (avg) (married)"): 	reg dowry_calc 		wealth_measure 		female i.caste  	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"


	* relative income survey * 

	replace wealth_measure = rel_income_svy

	eststo relsvy_f_c , title("Rank in caste wealth distribution (svy)"): 	reg dowry_calc 		wealth_measure 		female i.caste  	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"
	estadd local  female_d 		"Yes"

	replace wealth_measure = rel_income_svy_m

	eststo relsvym_f_c , title("Rank in caste wealth distribution (svy) (married)"): 	reg dowry_calc 		wealth_measure 		female i.caste  	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"




	* Predicted SVY Income *

	replace wealth_measure = rel_income_svy_hat

	eststo relpredsvy_f_c , title("Rank in caste wealth distribution (2SLS)"): 	reg dowry_calc 		wealth_measure 		female i.caste  	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"
	estadd local  female_d 		"Yes"


	replace wealth_measure = rel_pc_income_svy_hat

	eststo relpcpredsvy_f_c , title("Rank in caste wealth distribution (2SLS.pc)"): 	reg dowry_calc 		wealth_measure 		female i.caste  	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"
	estadd local  female_d 		"Yes"



	* Predicted 1871 Income *

	replace wealth_measure = rel_income_1871

	eststo rel1871_f_c , title("Rank in caste wealth distribution (2SLS)"): 	reg dowry_calc 		wealth_measure 		female i.caste  	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"
	estadd local  female_d 		"Yes"


	replace wealth_measure = rel_pc_income_1871

	eststo relpc1871_f_c , title("Rank in caste wealth distribution (2SLS.pc)"): 	reg dowry_calc 		wealth_measure 		female i.caste  	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"
	estadd local  female_d 		"Yes"


	* evidence of hyperagmy within the HH
	egen hhid = group(p_code v_code nirt_no)
	
	eststo dowry_withfamfe , title("Rank in caste wealth distribution (2SLS.pc)"): 	reghdfe dowry_calc 		female , absorb(hhid)  	/* ... per capita wealth ...*/
	sum dowry_calc if e(sample)
	estadd scalar mean_dowry 	r(mean)
	estadd local  caste_fe 		"Yes"
	estadd local  female_d 		"Yes"




*** Outputs ***
*---------------------------------------------------------------------------------------------------------------------------------------------------------------

	label variable 		dowry_frac_income_avg " "

/*
	tabout person using "${Output}/${Date}_Dowry_frac_Inc_v1.tex", replace ///
	sum cells(mean dowry_frac_income_avg N dowry_frac_income_avg ) format(2 0) ///
	style(tex) h3(" & & \\ ") bt
*/	



*** Table: Dowry & Wealth measures ***


*************
* FOR PAPER *
*************

* average *
/*
*** Table 6 - Dowry and Relative Wealth ***

esttab 	relsvy_f_c relavg_f_c relpcavg_f_c  ///
 		using "output/tables/table_reg_dowry_relwealth_forpaper.tex", replace /// 	"Table_Reg_Dowry_RelWealth_avg"
 		order(wealth_measure female) keep(wealth_measure) ///
 		cells( b( fmt(3) star vacant("--") )  se( fmt(3) par ) )  starlevels(* 0.10 ** 0.05 *** 0.01) ///
 		indicate("", label("" "")) ///
 		stats(mean_dowry female_d caste_fe N /*r2_a*/, labels("Mean of dep. variable " "Female dummy" "Caste FE" "Observations  " /*"adj. $ R^2 $"*/) fmt(2 0 0 0)) ///
	 	label nonotes /*booktabs*/ fragment collabels(none) nomtitles nolines plain substitute(_ _)  /// only the very core of the numbers, any additional formatting/headers in LaTex instead.
*/


* predicted *
/*
esttab 	relsvy_f_c relpredsvy_f_c relpcpredsvy_f_c  ///
 		using "${Output}/${Date}_Table_Reg_Dowry_RelWealth_pred.tex", replace ///
 		order(wealth_measure female) keep(wealth_measure) ///
 		cells( b( fmt(3) star vacant("--") )  se( fmt(3) par ) )  starlevels(* 0.10 ** 0.05 *** 0.01) ///
 		indicate("", label("" "")) ///
 		stats(mean_dowry female_d caste_fe N /*r2_a*/, labels("Mean of dep. variable " "Female dummy" "Caste FE" "Observations  " /*"adj. $ R^2 $"*/) fmt(2 0 0 0)) ///
	 	label nonotes /*booktabs*/ fragment collabels(none) nomtitles nolines plain substitute(_ _)  /// only the very core of the numbers, any additional formatting/headers in LaTex instead.
*/


* predicted 1871 *
/*
esttab 	relsvy_f_c rel1871_f_c relpc1871_f_c  ///
 		using "${Output}/${Date}_Table_Reg_Dowry_RelWealth_1871.tex", replace ///
 		order(wealth_measure female) keep(wealth_measure) ///
 		cells( b( fmt(3) star vacant("--") )  se( fmt(3) par ) )  starlevels(* 0.10 ** 0.05 *** 0.01) ///
 		indicate("", label("" "")) ///
 		stats(mean_dowry female_d caste_fe N /*r2_a*/, labels("Mean of dep. variable " "Female dummy" "Caste FE" "Observations  " /*"adj. $ R^2 $"*/) fmt(2 0 0 0)) ///
	 	label nonotes /*booktabs*/ fragment collabels(none) nomtitles nolines plain substitute(_ _)  /// only the very core of the numbers, any additional formatting/headers in LaTex instead.
*/





*** Figure: Local Polynomial - Partial Out Caste FE - Dowry inflation ***
/*
	Assumed process;
	y = f(x) + z + e 	// x wealth, z caste FE (incl _const), and female

	First stage (= approximate the nonparametric regression y=f(X) with polynomial b1*x + b2x^2)
	y = b1*x + b2*x^2 + a*z + e

	Second stage (=regress the dep. var. taking out the estimated caste FEs and correcting for mean ())

	y - a_hat*(z-z_mean) = lpoly(x)
*/



* Keep only observations for estimation *

local wealth_measure "rel_pc_income_avg" // "rel_pc_income_svy_hat" 	


drop if missing(dowry_calc) | missing(`wealth_measure') | missing(caste)
count // 948


// Note: dummies for FEs need to be stored and manipulated for 2nd stage, otherwise use i.caste
cap drop caste_* avg_caste_*
forvalues x=1/68{
	gen 	caste_`x'=0 
	replace caste_`x'=1 if caste==`x'
	egen 	avg_caste_`x' = mean(caste_`x') 	// effectively population share of this caste
}
sum avg_caste_*


**************** CHANGE TO ROBINSON ********************************
* First Stage - Approximate Lpoly *
reg dowry_calc 	  `wealth_measure' ///
				c.`wealth_measure'#c.`wealth_measure'  /// square
				female ///
				caste_* ///
				, noconst // 948
estimates store dowry_firststage


forvalues x=1/68{
	cap gen bhat_X_caste_`x'_avg = _b[caste_`x'] * (caste_`x' - avg_caste_`x')
}

egen caste_partial = rowtotal(bhat_X_caste_*)

gen dowry_no_caste = dowry_calc-caste_partial

********************************************************************


*************
* FOR PAPER *
*************

* Second Stage - Local polynomial *
* Average, all households - boys vs. girls *



*** Figure 5 - Dowry and Relative Wealth (by gender) ***

graph twoway  	(lpolyci dowry_no_caste   `wealth_measure'   if female==0 , bw(0.06)  lcolor(blue) fcolor("blue%30") alcolor("blue%30") alwidth(none) ) ///
 		  		(lpolyci dowry_no_caste   `wealth_measure'   if female==1 , bw(0.06)  lcolor(red) clpattern(dash) fcolor("red%30") alcolor("red%30") alwidth(none) ) ///
 		 , legend(order(2 4) label(2 "Males") label(4 "Females")) ytitle("Dowry (in thousands of Rupees)") xtitle("Rank in caste wealth distribution") ///
 		 ylabel( 100 200 300 ) ///
 		 graphregion(fcolor(white) lcolor(white)) 

*graph export "${Output}/${Date}_Fig_Dowry_Rank_Split.pdf", replace 	// caste FE factured out & Conf. Intv.
graph export "${out}/figures/fig_dowry_male_female.pdf", replace 	// caste FE factured out & Conf. Intv.




* exit

*** Combined for different wealth measures ***

**************** CHECK IF THIS NEEDS TO BE CHANGED TO ROBINSON TOO ************

	local Wealth_Vars "rel_pc_income_avg rel_pc_income_avg_m rel_pc_income_svy_hat rel_pc_income_svy_hat_m  rel_pc_income_1871" // per capita wealth rank measure relative to all in the caste, or relative to only those married

	foreach wealth_var of local Wealth_Vars {


			// Note: dummies for FEs need to be stored and manipulated for 2nd stage, otherwise use i.caste
			cap drop caste_* avg_caste_*
			forvalues x=1/68{
				gen 	caste_`x'=0 
				replace caste_`x'=1 if caste==`x'
				egen 	avg_caste_`x' = mean(caste_`x') 	/// effectively population share of this caste
						if !missing(dowry_calc) & !missing(`wealth_var') & !missing(caste) & !missing(female) 
			}
			sum avg_caste_*

			cap drop avg_female
			egen 	avg_female = mean(female) 	/// effectively population share of females
					if !missing(dowry_calc) & !missing(`wealth_var') & !missing(caste) & !missing(female) 


			* First Stage - Approximate Lpoly *
			reg dowry_calc 	  `wealth_var' ///
								c.`wealth_var'#c.`wealth_var'  /// square
								caste_* ///
								female ///
								, noconst // 948
			estimates store `wealth_var'_fs

			cap drop bhat_X_*

			forvalues x=1/68{
				cap gen bhat_X_caste_`x'_avg = _b[caste_`x'] * (caste_`x' - avg_caste_`x') ///
						if !missing(dowry_calc) & !missing(`wealth_var') & !missing(caste) & !missing(female) 
			}

			gen bhat_X_female_avg = _b[female] * (female - avg_female) ///
				if !missing(dowry_calc) & !missing(`wealth_var') & !missing(caste) & !missing(female) 

			cap drop female_partial
			gen female_partial = bhat_X_female_avg


			cap drop caste_partial
			egen caste_partial = rowtotal(bhat_X_caste_*) ///
				if !missing(dowry_calc) & !missing(`wealth_var') & !missing(caste) & !missing(female) 


			gen dowry_`wealth_var' = dowry_calc - caste_partial - female_partial ///
				if !missing(dowry_calc) & !missing(`wealth_var') & !missing(caste) & !missing(female) 
	}

*******************************************************************************
	
	
*************
* FOR PAPER *
*************

			* Second Stage - Local polynomial *

			* Average - all HH, or only married *

			*** Figure 4 - Dowry and Relative Wealth ***
			
			graph twoway  	(lpolyci dowry_rel_pc_income_avg_m rel_pc_income_avg_m  , bw(0.05) lcolor(red) clpattern(dash) fcolor("red%30") alcolor("red%30") lwidth(medthick) ) ///
							(lpolyci dowry_rel_pc_income_avg   rel_pc_income_avg  , bw(0.05)  lcolor(blue) fcolor("blue%30") alcolor("blue%30")  ) ///			 		  		
			 		 , legend( order(2 4) style(column) ///
			 		 			label(4 "Rank based on all households in the caste") ///
			 		 			label(2 "Rank based on households with married children") ///
			 		 		 ) ///
			 		  ytitle("Dowry (in thousands of Rupees)") xtitle("Rank in caste wealth distribution") ///
			 		  ylabel( 100 200 300 ) ///
			 		 graphregion(fcolor(white) lcolor(white)) 
 
			graph export  "${out}/figures/fig_dowries_relwealth.pdf" , replace 		// _Fig_Dowries_comb_m


			* Predicted survey income *
/*
			*** Table A1 - Dowry and Wealth (Alternative Methods to purge measuremtn error) ***

			graph twoway  	(lpolyci  dowry_rel_pc_income_svy_hat  rel_pc_income_svy_hat , bw(0.05)  color(red) lpattern(dash) lwidth(medthick) fintensity(inten30) alcolor(white) alwidth(none) ) ///
			 		  		(lpoly 	dowry_rel_pc_income_avg  rel_pc_income_avg , bw(0.05)  lcolor(blue) lwidth(medthick) ) ///
			 		 , legend( order(3 2) style(column) ///
			 		 			label(2 "Predicted income") ///
			 		 			label(3 "Average of survey and census income") ///
			 		 		 ) ///
			 		  ytitle("Dowry (in thousands of Rupees)") xtitle("Rank in caste wealth distribution") ///
			 		  ylabel( 100 200 300 ) ///
			 		 graphregion(fcolor(white) lcolor(white)) 

			graph export  "output/figures/fig_Dowries_comb_pred.pdf" , replace
*/

			* Predicted survey income *
			/*
			graph twoway  	(lpolyci  dowry_rel_pc_income_1871  rel_pc_income_1871 , bw(0.05)  color(red) lpattern(dash) lwidth(medthick) fintensity(inten30) alcolor(white) alwidth(none) ) ///
			 		  		(lpoly 	dowry_rel_pc_income_avg  rel_pc_income_avg , bw(0.05)  lcolor(blue) lwidth(medthick) ) ///
			 		 , legend( order(3 2) style(column) ///
			 		 			label(2 "Predicted 1871 income") ///
			 		 			label(3 "Average of survey and census income") ///
			 		 		 ) ///
			 		  ytitle("Dowry (in thousands of Rupees)") xtitle("Rank in caste wealth distribution") ///
			 		  ylabel( 100 200 300 ) ///
			 		 graphregion(fcolor(white) lcolor(white)) 

			graph export  "${Output}/${Date}_Fig_Dowries_comb_1871.pdf" , replace
			*/



tempfile dowry_data_analysis
save `dowry_data_analysis'

save "${coded}/DELETE_dowry_data_analysis", replace

***** delete finally save "${data}/coded/DELETE_dowry_data_analysis", replace
			
exit // END OF DO FIlE


