/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan Munshi and Soumya Swaminathan. 
Last updated: June 2, 2021
---------------------------------------------------------------------------
Do file: 18_age_diff_prop_married.do

Age at marriage and age gap between spouses descriptives correlation with relative income
=========================================================================*/

	*** Housekeeping

		clear all
		set more off
		capture log close
		set seed 1234
		//set matsize 11000

		global PredictedIncome pred_income_cluster_vfe

	*** Load main data set

		use "${coded}/DataForReg_coded.dta", clear
		
	*** Create rank variable	

		* rank based on predicted income per OWN youngest generation/ OWN child +2 (not directly estimated)
				gen pred_inc_younggen2p =.
				replace pred_inc_younggen2p = $PredictedIncome /(total_yg_own+2) if LivesWithFather==1 & LivesWithMother==1 & d_youngestgen==1
				lab var pred_inc_younggen2p "Predicted HH montlyincome divided by no. in the youngest generation+ # of parents"
				
				// only want to look at two parent HH
				//replace pred_inc_younggen2p = $PredictedIncome /(total_yg_own+1) if LivesWithFather==1 & LivesWithMother==0 & d_youngestgen==1
				//replace pred_inc_younggen2p = $PredictedIncome /(total_yg_own+1) if LivesWithFather==0 & LivesWithMother==1 & d_youngestgen==1
				
				gen log_pred_inc_younggen2p = log($PredictedIncome)
				
				sort caste log_pred_inc_younggen2p
				bys caste log_pred_inc_younggen2p : gen newid = 1 if _n==1
				by caste: gen rank_pred_inc_yg2p = sum(newid) if pred_inc_younggen2p!=.
				
				bys caste: egen num_ranks = max(rank_pred_inc_yg2p)

				gen ref_rank_pred_inc_yg2p = rank_pred_inc_yg2p/num_ranks
				lab var ref_rank_pred_inc_yg2p "Rank in within caste income distribution"
				
				drop newid
				drop num_ranks
					
		* Sample defined, same as always = single family HHs
		keep if fs==2 | fs==9
		// lab def fs 2 "Pe and family", add
		// lab def fs 9 "Pe and siblings living with their parents", add

	***********
	* Age Gap *
	***********

	*** age difference by cohort

	*** Figure in Appendix
		gen age_diff = father_C2_4 - mother_C2_4
		gen cohort_father = 2016 - father_C2_4
		gen cohort_mother = 2016 - mother_C2_4
	
		preserve

			collapse (mean) age_diff , by(cohort_father)
			set scheme s2color	
			tw (bar age_diff cohort_father if cohort_father>=1941 & cohort_father<=1995, xtitle("Husband's birth cohort") ///
			ytitle("Age difference between husband and wife (years)") ), ///
			graphregion(color(white)) bgcolor(white)
			graph export "${out}/figures/age_diff.pdf", replace
			
		restore
		
		
	*** age at marriage by relative wealth	
		set scheme s2color	
		tw (lpoly age_diff ref_rank_pred_inc_yg2p if age_diff>=0 & age_diff<=20, bw(0.03)  lcolor(gs6)), ///
		yscale(r(0 12)) ylabel(2(2)12) ///
		ytitle("Age gap between spouses (years)") ///
		xtitle("Rank in caste wealth distribution") ///
		graphregion(fcolor(white) lcolor(white)) 
		
		graph export "${out}/figures/age_gap_rank.pdf" , replace

	
	**************************************
	*** size of cohort
	**************************************

		/*	collapse (count) x, by(C2_4)
			replace x = x/1000
			
			tw (bar x C2_4 if C2_4>=18 & C2_4<=40, xtitle("Age") ///
			ytitle("Population") ), ///
			graphregion(color(white)) bgcolor(white)
			
			
			local bin_size = 10
			
			gen age_g = .
			
			forval i=1/4{
				local lower = `bin_size' * (`i'-1)
				local upper = `bin_size' * `i'
				replace age_g = `i' if C2_4>=`lower' & C2_4<=`upper'
			}
			
			* all together
				collapse (count) x, by(age_g)
				
				replace x = x/1000
				
				tw (bar x age_g if age_g>=2 & age_g<=4, xtitle("Age group") ///
				ytitle("Population") ), ///
				graphregion(color(white)) bgcolor(white)			
			
			
			* by gender
				collapse (count) x, by(age_g IsFemale)
				
				replace x = x/1000
				
				tw (bar x age_g if age_g>=2 & age_g<=4, by(IsFemale) xtitle("Age group") ///
				ytitle("Population") ), ///
				graphregion(color(white)) bgcolor(white)
		*/
	*******************	
	*** proportion married by age
	*******************
	*** Figure in Appendix
		gen d_marr = .
		replace d_marr = 0 if C2_5==0
		replace d_marr = 1 if C2_5==1

		gen d_evermarr = 0
		replace d_evermarr = 1 if C2_5>0

		preserve
			gen tot_marr =1 if d_marr!=.
			gen tot_evermarr =1
				
			
			keep if C2_4>=18 & C2_4<=40
			
			
			collapse (sum) d_marr tot_marr d_evermarr tot_evermarr , by(C2_3 C2_4)
			gen prop_marr = d_marr/tot_marr
			gen prop_evermarr = d_evermarr/tot_evermarr
			
			keep C2_3 C2_4 prop_*
			
			reshape wide prop_marr prop_evermarr, i(C2_4) j(C2_3)
			set scheme s2color	
			tw 	(connected prop_evermarr1 C2_4, msymbol(t) mcolor(blue) lcolor(blue) xtitle("Age") ytitle("Proportion married")) ///
				(connected prop_evermarr2 C2_4, msymbol(o) mcolor(red) lpattern("-") lcolor(red) ///
				lwidth(medthick) xtitle("Age") ytitle("Proportion married")), ///
				legend(order(1 "Males" 2 "Females" )) ///
				graphregion(color(white)) bgcolor(white)
			graph export "${out}/figures/prop_marr_age.pdf", replace

		restore	
	
	/*	
		esttab pr_marr using "$sexselection/output/tables/pr_marr.tex", ///
		drop(_cons) replace se booktabs ///
		stats(control_mean N caste_fe village_fe, ///
			labels(`"Mean of dependent variable"' ///
					`"Observations"' ///
					`"Caste FE"')) ///
			coeflabels(ref_rank_pred_inc_yg2p "Rank in caste per capita wealth distribution") ///
			star(^{*} 0.10 ^{**} 0.05 ^{***} 0.01) nomtitles ///
			nonotes
		*/
	
	
	**************************************
	*** age at marriage by relative wealth
	**************************************
	use "${coded}/Survey_data_formerge", clear
	
	keep P_CODE V_CODE NIRT_NO RSN MPR_ROW_ID_SEC_E E3 E5 E4
	
	rename P_CODE p_code 
	rename V_CODE v_code 
	rename NIRT_NO nirt_no 
	rename RSN rsn
	rename MPR_ROW_ID_SEC_E row_id 
	rename E3 ownchild_rsn
	
	* mereg dowry dataset which has relative income
	merge 1:1 p_code v_code nirt_no row_id ownchild_rsn rsn using "${coded}/DELETE_dowry_data_analysis", keep(3)
	//qui do "code/coding/Dowry_Income_Analyses_FINAL.do"
	
	//use `dowry_data_analysis', clear --> uncomment finally, this is a tempfile being created in the do file "code/coding/Dowry_Income_Analyses_FINAL.do"
	set scheme s2color	
	tw 	(lpoly E5 rel_pc_income_avg if E4==1, bw(0.2) lpattern("-") lcolor(red)) ///
		(lpoly E5 rel_pc_income_avg if E4==2, bw(0.2) lcolor(blue)), ///
		xtitle("Rank in caste wealth distribution") ///
		ytitle("Age at marriage") ///
		legend(order(2 "Males" 1 "Females" )) ///
		graphregion(fcolor(white) lcolor(white)) 

		graph export "${out}/figures/age_at_marr_rank.pdf" , replace
		
		

		
