/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan 
Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 5_dataprep.do

- Input: CompleteData_clean_10Oct2015.dta
		 Historical_data.dta
- Output: DataForReg.dta
=========================================================================*/

use "${coded}/CompleteData_clean_10Oct2015.dta", clear

* merge with historical data to run the FS regressions within the 2sls command
merge m:1 A2 using "${coded}/Historical_data.dta"

rename _merge curr_hist_match

keep if curr_hist_match==3| curr_hist_match==1 // villages for which we have both the historical and the current information
	
* Historical data

	* The historical wealth statistic should be demand on account of land revenue divided by cultivated area.

	gen dd_landrev = (dd_landrev_rs+ (dd_landrev_a/16) + (dd_landrev_p/192))/1000
	gen avg_rpa_cult_wet = (avg_rpa_cult_wet_rs+ (avg_rpa_cult_wet_a/16) + (avg_rpa_cult_wet_p/192))/1000
	gen avg_rpa_cult_dry = (avg_rpa_cult_dry_rs+ (avg_rpa_cult_dry_a/16) + (avg_rpa_cult_dry_p/192))/1000

	* 1 anna = 1/16 of a rupee
	* 1 pies = 1/192 of a rupee (old paisa, pre-1950) - not paisa

	label var dd_landrev "DD on account of land revenue"

	* dividing by area occupied for cultivation
	gen hist_wealth1 = dd_landrev/areaoccupiedforcultivation
	lab var hist_wealth1 "DD on account of land revenue per cultivated acre"
	
	* population density in village
	//gen area_sqkm = areainacres/247.105

	gen pop_density = population/areainacres


count

* Generating the total monthly income of household i.e. adding monthly income from all sources(other than rent from land) 
* and profit from land owned, leased or rented by the household
gen C9_thousand=0
replace C9_thousand=C9 if C9_Unit=="0"
replace C9_thousand=C9*100 if C9_Unit=="1" // all income from land now in thousands

gen C8_thousand=0
replace C8_thousand=C8 if C8_Unit=="0"
replace C8_thousand=C8*100 if C8_Unit=="1"

gen monthlyincome=C9_thousand+(C8_thousand/12)
lab var monthlyincome "Household monthly income"

*-----------------*
* Hsec enrollment *
*-----------------*
* Higher secondary scool enrollment separately for boys and girls
gen IsMale = 1 - IsFemale

gen d_hsecstudent = .
replace d_hsecstudent = 0 if C2_4>=15 & C2_4<=18 & C2_5==0
replace d_hsecstudent = 1 if C2_4>=15 & C2_4<=18 & C2_8 == "112" & C2_5==0
lab var d_hsecstudent "Indicator for enrollment in higher secondary school for 15-18 year olds"

gen d_hsecstudent_b = d_hsecstudent if C2_3==1
gen d_hsecstudent_g = d_hsecstudent if C2_3==2

*-----------------*
* child sex dummy *
*-----------------*
* Girl aged 0-6 years
gen d_girl6=.
replace d_girl6 = 0 if C2_4>=0 & C2_4<=6
replace d_girl6 = 1 if C2_4>=0 & C2_4<=6 & C2_3==2
lab var d_girl6 "Dummy = 1 if girl between the age of 0-6 years, 0 for boys between the age of 0-6 years"

*-----------------------------------*
* female labour force participation *
*-----------------------------------*
gen d_unemployed_f =.
replace d_unemployed_f = 0 if C2_3==2 & C2_4>=21 & C2_4<=30
replace d_unemployed_f = 1 if C2_3==2 & C2_4>=21 & C2_4<=30 & (C2_8=="111"|C2_8=="112"|C2_8=="113"|C2_8=="114"|C2_8=="115")

gen d_employed_f = 1 - d_unemployed_f
lab var d_employed_f "Indicator for female labor force participation"


***********************************
* defining the number of children *
***********************************

* youngest generation
	* Assigning hh members to generations - youngestgen, secondgen, thirdgen and fourthgen
	do "${subcode}/5_1_assigning_to_generations.do"
	
	count
	
	* Houseold size
	gen x=1
	bys HHid: egen HHsize = total(x)
	
	* total number of children in the household with two parents
	gen d_yg_own = 0 if d_youngestgen==0 & LivesWithFather==1 & LivesWithMother==1 // added code if d_youngestgen==0 & LivesWithFather==1 & LivesWithMother==1 on 19-04-2016
	replace d_yg_own = 1 if d_youngestgen==1 & LivesWithFather==1 & LivesWithMother==1
	
	bys HHid: egen total_yg_own = total(d_yg_own)	
	
	bys HHid: egen total_youngestgen = total(d_youngestgen)
	
	* looking at only the under 21 children
	gen yg_21 = 0
	replace yg_21 = 1 if d_youngestgen==1 & LivesWithParent==1 & C2_4<=21
	
	gen yg_21_own = 0
	replace yg_21_own = 1 if d_yg_own==1 & C2_4<=21
	
	bys HHid: egen num_yg_21_own = total(yg_21_own)

	bys HHid: egen num_yg_21 = total(yg_21)
	
	preserve
		keep if fs==2| fs==9
		
		* attaching parents characteristics to the children
		do "${subcode}/5_2_parents_children.do"
		keep IndividualId father_* mother_*
		tempfile parentchar29
		save `parentchar29'
	restore

merge 1:1 IndividualId using `parentchar29', keep(1 3) nogen
	
	* birth order for fs==2| fs==9
	preserve
		// need to calculate birthorder
		keep if fs==2| fs==9
		keep if LivesWithFather==1 & LivesWithMother==1 & d_youngestgen==1
		gsort HHid -C2_4
		bys HHid: gen birthorder = _n
		keep IndividualId birthorder
		tempfile birthorder29
		save `birthorder29'
	restore
	
	merge 1:1 IndividualId using `birthorder29', keep(1 3) nogen
	
	forval i = 1/2{
	gen d_bo`i' = .
	replace d_bo`i' = 0 if birthorder!=`i'
	replace d_bo`i' = 1 if birthorder==`i'
	
	lab var d_bo`i' "Dummy for birth order = `i'"
}

	* generate birthorder dummies - all but the first
	gen d_bo_other = .
	replace d_bo_other = 0 if birthorder<=2 & birthorder!=. // for 1, 2
	replace d_bo_other = 1 if birthorder>2  & birthorder!=. // for 3 or higher

* birth order dummies for robustness regression
	forval i = 1/4{
	gen d_bo_rob`i' = .
	replace d_bo_rob`i' = 0 if birthorder!=`i'
	replace d_bo_rob`i' = 1 if birthorder==`i'
	
	lab var d_bo_rob`i' "Dummy for birth order = `i'"
}

	* generate birthorder dummies - all but the first
	gen d_bo_rob_other = .
	replace d_bo_rob_other = 0 if birthorder<=4 & birthorder!=. // for 1, 2, 3 or 4
	replace d_bo_rob_other = 1 if birthorder>4  & birthorder!=. // for 5 or higher
	
	
	/* looking at only the under 21 children
	gen yg_21 = 0
	replace yg_21 = 1 if d_youngestgen==1 & LivesWithParent==1 & C2_4<=21
	
	gen yg_21_own = 0
	replace yg_21_own = 1 if d_yg_own==1 & C2_4<=21
	
	bys HHid: egen num_yg_21_own = total(yg_21_own)

	bys HHid: egen num_yg_21 = total(yg_21) */

	* generated caste - village	id
	sort A2 caste
	egen caste_villid = group(A2 caste)
	tostring caste_villid, replace

	tempfile file1
	save `file1'
	
//saveold "Census data/PrepData_$date.dta", replace 

//use "Census data/PrepData_$date.dta", clear
	
	duplicates drop HHid, force
	
	* count HH in each caste
	gen c=1
	egen numHH_caste = count(c), by(caste)
	
	keep HHid numHH_caste

merge 1:m HHid using `file1', keep(3) nogen

save "${coded}/DataForReg.dta", replace 


* Create relative education database

*- Import data 
use "${coded}/DataForReg.dta", clear

	gen sex = C2_3
	gen age = C2_4


		*** Education Rank by age*** 
		egen 	rank_educ 		= rank(EdYears)
		replace rank_educ 		= rank_educ-1
		egen 	rank_educ_max 	= max(rank_educ)

		gen rel_educ = 			rank_educ/rank_educ_max
		drop 					rank_educ rank_educ_max


		*** Education Rank by age and gender *** 
		bys age sex: 		egen 	rank_educ 		= rank(EdYears)
		replace 					rank_educ 		= rank_educ-1
		by age sex: 		egen 	rank_educ_max 	= max(rank_educ)

		gen rel_educ_sex = 			rank_educ/rank_educ_max
		drop 						rank_educ rank_educ_max


		*** Education Rank by age and caste *** 
		bys age caste: 		egen 	rank_educ 		= rank(EdYears)
		replace 					rank_educ 		= rank_educ-1
		by age caste: 		egen 	rank_educ_max 	= max(rank_educ)

		gen rel_educ_caste = 		rank_educ/rank_educ_max
		drop 						rank_educ rank_educ_max


		*** Education Rank by age, gender and caste *** 
		bys age sex caste: 	egen 	rank_educ 		= rank(EdYears)
		replace 					rank_educ 		= rank_educ-1
		by age sex caste: 	egen 	rank_educ_max 	= max(rank_educ)

		gen rel_educ_sex_caste = 	rank_educ/rank_educ_max
		drop 						rank_educ rank_educ_max


		local age_span = 1


		forvalues age_span = 0/10 {

			gen 	rel_educ_`age_span'cns = .

			forvalues age_x = 16/56 { 

				*** Education Rank by age, gender and caste *** 
				bys sex caste: 	egen 	rank_educ 		= rank(EdYears)		if age>=`age_x'-`age_span' &  age<=`age_x'+`age_span'
				replace 				rank_educ 		= rank_educ-1 		if age>=`age_x'-`age_span' &  age<=`age_x'+`age_span'
				bys  sex caste: 	egen 	rank_educ_max 	= max(rank_educ) 	if age>=`age_x'-`age_span' &  age<=`age_x'+`age_span'

				replace rel_educ_`age_span'cns = 	rank_educ/rank_educ_max 	if age==`age_x'
				drop 							rank_educ rank_educ_max

			}

		}
			

	keep sex age caste EdYears rel_educ*

	duplicates drop  	// keep 1 obs for each combination of age, educ sex caste etc.

	save "${coded}/2018-01-10_RelEduc.dta", replace