/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 13_lpoly_castebycaste.do
=========================================================================*/

* Please note: this code uses the predicted income defined without Village FE and
* with no clustering at the village and panchayat level

clear all
set more off
capture log close
set seed 12345678

********************************
* SET NUMBER OF INCOME CLASSES *
********************************
global numincls = 10
********************************

*****************
* SET AGE GROUP *
*****************
global agegrp = "06"

******************

use "${coded}/DataForReg.dta", clear

global PredictedIncome pred_income

keep if curr_hist_match==3 // villages for which we have both the historical and the current information
	
	gen d_06 = 0
	replace d_06 = 1 if d_girl6!=.           
	bys HHid: egen HHunder6 = max(d_06)

*********************************************
* ORIGINAL REGRESSION outside the bootstrap	*
*********************************************
sort HHid IndividualId

* First stage
	gen rand = runiform()
	cap isid HHid rand, sort
	bys HHid (rand): keep if _n == 1
	//duplicates drop HHid, force

	* (1) Using hist_wealth1 "DD on account of land revenue per cultivated acre"
	xi: reg monthlyincome i.caste*hist_wealth1, cluster(A2)
	testparm hist_wealth1 _IcasXhist* // F-stat (298K) 20.40
	predict pred_income

	* count HH in each caste
	gen c1 = 1 if fs==2|fs==9
	egen numHH_caste_fs29 = count(c1), by(caste)
	lab var numHH_caste_fs29 "Number of fs2/9 HH in each caste"

	* count HH with atleast one under six and fs=2| fs=9
	gen c2 = 1 if HHunder6==1 & (fs==2|fs==9)
	egen numHH_caste_fs29_u6 = count(c2), by(caste)
	lab var numHH_caste_fs29_u6 "Number of fs2/9 HH in each caste with atleast one child under 6"
	
	keep HHid pred_* numHH_caste* d_06
		
	merge 1:m HHid using "${coded}/DataForReg.dta", keep(3) nogen

	* interactign with the coefficient of variation
	bys caste: egen meancaste_pred_income = mean($PredictedIncome)

	bys caste: egen sd_pred_income = sd($PredictedIncome)

	gen cv_pred_income = sd_pred_income/meancaste_pred_income
			
	* II * rank based on predicted income per OWN youngest generation/ OWN child +2 (not directly estimated)
			gen pred_inc_younggen2p =.
			replace pred_inc_younggen2p = $PredictedIncome /(total_yg_own+2) if LivesWithFather==1 & LivesWithMother==1 & d_youngestgen==1
			lab var pred_inc_younggen2p "Predicted HH montlyincome divided by no. in the youngest generation+ # of parents"
			
			// only want to look at two parent HH
			//replace pred_inc_younggen2p = $PredictedIncome /(total_yg_own+1) if LivesWithFather==1 & LivesWithMother==0 & d_youngestgen==1
			//replace pred_inc_younggen2p = $PredictedIncome /(total_yg_own+1) if LivesWithFather==0 & LivesWithMother==1 & d_youngestgen==1
			
			gen log_pred_inc_younggen2p = log(pred_inc_younggen2p)
			
			sort caste log_pred_inc_younggen2p
			bys caste log_pred_inc_younggen2p : gen newid = 1 if _n==1
			by caste: gen rank_pred_inc_yg2p = sum(newid) if pred_inc_younggen2p!=.
			
			bys caste: egen num_ranks = max(rank_pred_inc_yg2p)

			gen ref_rank_pred_inc_yg2p = rank_pred_inc_yg2p/num_ranks
			lab var ref_rank_pred_inc_yg2p "Rank in within caste income distribution"
			
			drop newid
			drop num_ranks
			
* III * rank based on predicted income per OWN youngest generation/ OWN child +2 (not directly estimated)
	  * for all HH in caste with atleast one under 6
	  * not just HH where child lives with both parents 
			gen pred_inc_yg2p06 =.
			replace pred_inc_yg2p06 = $PredictedIncome /(total_yg_own+2) if LivesWithFather==1 & LivesWithMother==1 & d_girl6!=.
			lab var pred_inc_yg2p06 "Predicted HH montlyincome divided by no. in the youngest generation+ 2 parents"
			
			gen log_pred_inc_yg2p06 = log(pred_inc_yg2p06)
			
			sort caste log_pred_inc_yg2p06
			bys caste log_pred_inc_yg2p06 : gen newid = 1 if _n==1
			by caste: gen rank_pred_inc_yg2p06 = sum(newid) if pred_inc_yg2p06!=.
			
			bys caste: egen num_ranks = max(rank_pred_inc_yg2p06)

			gen ref_rank_pred_inc_yg2p06 = rank_pred_inc_yg2p06/num_ranks
			lab var ref_rank_pred_inc_yg2p06 "Rank in within caste income distribution"
			
			drop newid
			drop num_ranks	
			
*Prepare data for second stage
	keep if fs==2 | fs==9
	// lab def fs 2 "Pe and family", add
	// lab def fs 9 "Pe and siblings living with their parents", add

	
* from smodel_regs_2017_03_13	
* 2 * individual castes
keep if numHH_caste_fs29_u6>=50	
	
* generate caste dummies and mean of caste dummies
levelsof caste, local(castenumber) 
foreach x of local castenumber{
		di "Caste running is caste = `x'"
		gen d_caste`x' = 0
		replace d_caste`x' = 1 if caste==`x'
		
		* generate mean of caste dummies	
		egen mcaste`x'=mean(d_caste`x')
}

egen mean_pred_income = mean($PredictedIncome)
egen mean_mother_EdYears = mean(mother_EdYears)
egen mean_father_EdYears = mean(father_EdYears)
egen mean_d_bo1 = mean(d_bo1)
egen mean_d_bo2 = mean(d_bo2)
	
* generate polynomials
forval i=2/6{
	gen rr_pred_inc_yg2p_`i' = ref_rank_pred_inc_yg2p^`i'
	gen pred_income_`i' = pred_income^`i'
	
	gen rr_pred_inc_yg2p06_`i' = ref_rank_pred_inc_yg2p06^ `i'
		
	* generate mean of predicted income
		egen m_pred_inc_`i'=mean(pred_income_`i')
}

egen m_pred_inc_younggen2p=mean(pred_inc_younggen2p)

* number of 0-6 year olds in a caste: to be reported as part of the graphs
gen d_0to6 = 0
replace d_0to6 = 1 if d_girl6!=.           
bys caste: egen num_0to6= total(d_0to6)


********************************************************************************
************************************
* create data for structural model *
************************************

save "${coded}/indlevel_smodel.dta", replace
	
	//do "code/data_smodel.do"

********************************************************************************
********************************************************************************

	* use HH level data to calculate income classes by caste
	set seed 12345678
	sort HHid IndividualId
	gen rand = runiform()
	cap isid HHid rand, sort
	by HHid: keep if _n == 1

	//duplicates drop HHid, force

	global income pred_inc_younggen2p
	gen inc_cls = .

	* same as saying keep if numHH_caste_fs29_u6>=500
	keep if caste==28| caste==38| caste==1| caste==14| caste==33 |caste==5|caste==10|caste==23|caste==7 ///
	| caste==44 | caste==17 | caste==4



	* Create income classes for castes
	
	levelsof caste if numHH_caste_fs29_u6>=150, local(castenumber)
	foreach x of local castenumber{
				
				//sort caste HHid rand $income
				xtile inc_cls_`x' = $income if caste==`x', nq($numincls)
				di "caste = `x'"
				//tab inc_cls_`x' if caste==`x'
				replace inc_cls = inc_cls_`x' if caste==`x'
			}

	* drop values with no income class assigned
	drop if inc_cls==.
	gen numcls=.

	* check how many income classes created per caste
	* stata forces identical observations to be in the same quantile
		levelsof caste if numHH_caste_fs29_u6>=100, local(castenumber)
		foreach x of local castenumber{
			isid caste inc_cls HHid 
			sort caste inc_cls HHid // stablization
			by caste inc_cls: replace numcls = 1 if _n==1 & caste==`x'

		}
		by caste: replace numcls = sum(numcls)
		
	by caste: egen tot_numcls = max(numcls)
	tab caste tot_numcls

	* keep only the caste and income class data for each HHid
	keep HHid caste inc_cls
	keep if inc_cls!=.
	tempfile HHinc_cls
	save `HHinc_cls'

	* merge back to individual level data to collapse
	use "${coded}/indlevel_smodel.dta", clear
	merge m:1 HHid using `HHinc_cls'

	keep if _m==3

	* our benchamrk regressions
		local ranklist pred_inc_yg2p
		local reglist d_girl6
				foreach reg of local reglist{
					foreach ranktype of local ranklist{
						* income per child *
						reg `reg' ref_rank_`ranktype', robust cluster(A2)

						areg `reg' ref_rank_`ranktype', robust cluster(A2) absorb(caste)
					}
				}

	* collapse to caste - income class level
	collapse (mean) d_girl6 $income (sum)d_$agegrp , by(caste inc_cls)
	drop if inc_cls==.

	* regress fraction of girls on average income
	reg d_girl6 $income [fweight=d_$agegrp]

	* regress fraction of girls on income class dummies
	reg d_girl6 i.inc_cls

		* same regression graphically
		sort inc_cls caste 
		by inc_cls: egen mean_frac = mean(d_girl6)
		tw line mean_frac inc_cls

	sort caste inc_cls
	ren pred_inc_younggen2p inc
	gen f = d_girl6 * d_06
	gen m = d_06 - f
	ren d_06 t
	gen csr = m/f
	gen X = (m+f)/2
	gen Hk = (csr-1)/(csr+1)
	order inc m f t csr Hk X caste inc_cls d_girl6 mean_frac
	levelsof caste, local(levels) 
	foreach l of local levels {
		preserve
		keep if caste == `l'
		drop caste inc_cls d_girl6 mean_frac
		outsheet using "$raw/06_8class/caste`l'.csv", comma replace
		restore
	}