/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan 
Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 7_2_coding_breg_bs.do
Purpose: Prep the data to run bootstrap
=========================================================================*/

* save the data you are using for the code
tempfile data_used
save "`data_used'"

keep if curr_hist_match==3 // villages for which we have both the historical and the current information

*********************************************
* ORIGINAL REGRESSION outside the bootstrap	*
*********************************************

* parental education
	bys HHid: egen max_father_ed = max(father_EdYears) 
	bys HHid: egen min_father_ed = min(father_EdYears)
	gen d_father_ed_diff = 0
	replace d_father_ed_diff = 1 if max_father_ed!=min_father_ed // = 1 means there are multiple fathers in the HH

	* we care aboout the case when father education != primary earner education

		* PE and spouse education
		gen A_ed = EdYears if C2_6=="A"
		bys HHid: egen max_A_ed = max(A_ed)
		drop A_ed
		rename max_A_ed A_ed

		gen W_ed = EdYears if C2_6=="W"
		bys HHid: egen max_W_ed = max(W_ed)
		drop W_ed
		rename max_W_ed W_ed

		gen H_ed = EdYears if C2_6=="H"
		bys HHid: egen max_H_ed = max(H_ed)
		drop H_ed
		rename max_H_ed H_ed

		* cases where multiple fathers in HH and dgirl6 father is not the PE
		gen diff_father_A_ed = 1 if A_ed!=father_EdYears & d_girl6!=. & d_father_ed_diff==1
		// there were 71 such cases, however there is only 3 cases where PE education is not equal to parental education 
		// because the PE's brother/WB/FW6 is under 6 - for those we use A's education
		// all others are other rogue children e.g. S6 or WB1
		// or HHs where PE is female
		// so we can safely use the father's education for under 6 children in the HH for wealth prediction

		gen father_EdYears_under6 = father_EdYears if d_girl6!=.
		gen mother_EdYears_under6 = mother_EdYears if d_girl6!=.

		bys HHid: egen max_father_ed_under6 = max(father_EdYears_under6) 
		bys HHid: egen min_father_ed_under6 = min(father_EdYears_under6)

		gen d_father_ed_under6_diff = 0
		replace d_father_ed_under6_diff = 1 if max_father_ed_under6!=min_father_ed_under6 
		
		// 3 cases for which there is a diff, for these we will use A's education as father's education and W's education as mother's education
		// over all we can use PE and spouse education as parental education variables since all but 3 HHs with under 6 children the parental education is the PE and spouse education, 
		// even for those 3 HHs the under 6 children are the PE's youngest sibling or WB or S1 etc and PE education seems like the relevant variable

		* HH male head education and female head education (PE and wife/husband)
		gen HH_malehead = 1 if C2_6=="A" & C2_3==1
		replace HH_malehead = 0 if C2_6=="A" & C2_3==2
		bys HHid: egen max_malehead = max(HH_malehead)
		drop HH_malehead
		rename max_malehead HH_malehead

		gen HH_malehead_ed = A_ed if HH_malehead==1 // male head i.e. A and W combination
		replace HH_malehead_ed = H_ed if HH_malehead==0 // female head i.e. A and H combination

		gen HH_femalehead_ed = A_ed if HH_malehead==0 // male head i.e. A and W combination
		replace HH_femalehead_ed = W_ed if HH_malehead==1 // female head i.e. A and H combination

* cleaning land variables: units in Acres (1) or Cents (0)

	* cleaning variables
		replace C6_Unit = "0" if (C6_Unit=="-1" | C6_Unit=="")

		gen C5_acre = C5
		replace C5_acre = C5/100 if C5_Unit == "0"

		gen C6_acre = C6
		replace	C6_acre = C6/100 if C6_Unit == "0"

		replace C5_acre = C6_acre if C5_Unit==C6_Unit & C6_acre> C5_acre & C6_acre!=.
		replace C5_acre = C6_acre if C6_acre> C5_acre & C6_acre!=. & C5_acre ==0
		
	* interaction variable	
		gen hist_wealth1_C5 = hist_wealth1 * C5_acre		
		gen hist_wealth1_C6 = hist_wealth1 * C6_acre

	* per capita monthly income
		gen monthlyincome_pc = monthlyincome/(total_yg_own+2)
	
	* age of eldest child in the youngest generation
	bys HHid: egen age1 = max(C2_4) if d_youngestgen==1 & LivesWithParent==1
	bys HHid: egen age_old = max(age1)
	drop age1

	* age of youngest child in the youngest generation / or youngest person in HH
	bys HHid: egen age_young = min(C2_4)
		
* First stage
	duplicates drop HHid, force

	* (1) Using hist_wealth1 "DD on account of land revenue per cultivated acre"
	xi: reg monthlyincome i.caste*hist_wealth1, cluster(A2)
	testparm hist_wealth1 _IcasXhist* // F-stat (298K) 20.40
	predict pred_income
	
	* (2a) Using hist_wealth1 "DD on account of land revenue per cultivated acre" 
	* alternative specification with clustering on caste and panchayat
	* only castes with at least 10 HH
	egen caste_A2 = group(caste A2)
	bys caste: egen count_caste = count(caste)
	xi: reg monthlyincome i.caste*hist_wealth1 i.A2 if count_caste>10, cluster(caste_A2)
	predict pred_income_cluster_vfe
	testparm hist_wealth1 _IcasXhist* _IA2* // F-stat 30.05

	* (3) alternative measure of HH welath using PCA on education, income and landholding
	pca HH_malehead_ed HH_femalehead_ed monthlyincome_pc C5_acre
	predict pred_income_pca
	
	* count HH in each caste
	gen c1 = 1 if fs==2|fs==9
	egen numHH_caste_fs29 = count(c1), by(caste)
	lab var numHH_caste_fs29 "Number of fs2/9 HH in each caste"
		
	keep HHid pred_* numHH_caste* C5* C6* caste_A2
		
	merge 1:m HHid using "`data_used'", keep(3) nogen			

* mother LFP
	gen mother_unemployed =.
	replace mother_unemployed = 0 if mother_IndividualId!="" & mother_C2_4>=15 & mother_C2_4<=59
	replace mother_unemployed = 1 if mother_IndividualId!="" & mother_C2_4>=15 & mother_C2_4<=59 & ///
	(mother_C2_8=="111"|mother_C2_8=="112"|mother_C2_8=="113"|mother_C2_8=="114"|mother_C2_8=="115")

	gen mother_employed = 1 - mother_unemployed
	lab var mother_employed "Indicator for `i' mother's labor force participation (15-59 years)"
		
	su mother_employed

* HIGH SCHOOL ENROLLMENT *
	gen hsc_enroll = .
	replace hsc_enroll = 0 if C2_4>=14 & C2_4<=17 & C2_5==0
	replace hsc_enroll = 1 if C2_4>=14 & C2_4<=17 & C2_8 == "112" & C2_5==0
	lab var hsc_enroll "Indicator for enrollment in higher secondary school for 14-17 year olds"

	gen hsc_enroll_g = hsc_enroll if C2_3==2
	gen hsc_enroll_b = hsc_enroll if C2_3==1

	su hsc_enroll if C2_3==1
	su hsc_enroll if C2_3==2 // female

* dummy for 7 to 13 year olds
	gen d_girl713=.
	replace d_girl713 = 0 if C2_4>=7 & C2_4<=13
	replace d_girl713 = 1 if C2_4>=7 & C2_4<=13 & C2_3==2
	lab var d_girl713 "Dummy = 1 if girl between the age of 7-13 years, 0 for boys between the age of 7-13 years"	

* parental education ( used in the first stage regression)
	bys HHid: egen max_father_ed = max(father_EdYears) 
	bys HHid: egen min_father_ed = min(father_EdYears)
	gen d_father_ed_diff = 0
	replace d_father_ed_diff = 1 if max_father_ed!=min_father_ed // = 1 means there are multiple fathers in the HH

	* we care aboout the case when father education != primary earner education

		* PE and spouse education
		gen A_ed = EdYears if C2_6=="A"
		bys HHid: egen max_A_ed = max(A_ed)
		drop A_ed
		rename max_A_ed A_ed

		gen W_ed = EdYears if C2_6=="W"
		bys HHid: egen max_W_ed = max(W_ed)
		drop W_ed
		rename max_W_ed W_ed

		gen H_ed = EdYears if C2_6=="H"
		bys HHid: egen max_H_ed = max(H_ed)
		drop H_ed
		rename max_H_ed H_ed

		* cases where multiple fathers in HH and dgirl6 father is not the PE
		gen diff_father_A_ed = 1 if A_ed!=father_EdYears & d_girl6!=. & d_father_ed_diff==1
		// there were 71 such cases, however there is only 3 cases where PE education is not equal to parental education 
		// because the PE's brother/WB/FW6 is under 6 - for those we use A's education
		// all others are other rogue children e.g. S6 or WB1
		// or HHs where PE is female
		// so we can safely use the father's education for under 6 children in the HH for wealth prediction

		gen father_EdYears_under6 = father_EdYears if d_girl6!=.
		gen mother_EdYears_under6 = mother_EdYears if d_girl6!=.

		bys HHid: egen max_father_ed_under6 = max(father_EdYears_under6) 
		bys HHid: egen min_father_ed_under6 = min(father_EdYears_under6)

		gen d_father_ed_under6_diff = 0
		replace d_father_ed_under6_diff = 1 if max_father_ed_under6!=min_father_ed_under6 
		
		// 3 cases for which there is a diff, for these we will use A's education as father's education and W's education as mother's education
		// over all we can use PE and spouse education as parental education variables since all but 3 HHs with under 6 children the parental education is the PE and spouse education, 
		// even for those 3 HHs the under 6 children are the PE's youngest sibling or WB or S1 etc and PE education seems like the relevant variable

		* HH male head education and female head education (PE and wife/husband)
		gen HH_malehead = 1 if C2_6=="A" & C2_3==1
		replace HH_malehead = 0 if C2_6=="A" & C2_3==2
		bys HHid: egen max_malehead = max(HH_malehead)
		drop HH_malehead
		rename max_malehead HH_malehead

		gen HH_malehead_ed = A_ed if HH_malehead==1 // male head i.e. A and W combination
		replace HH_malehead_ed = H_ed if HH_malehead==0 // female head i.e. A and H combination

		gen HH_femalehead_ed = A_ed if HH_malehead==0 // male head i.e. A and W combination
		replace HH_femalehead_ed = W_ed if HH_malehead==1 // female head i.e. A and H combination	
		
		lab var pred_income "Predicted income"
		lab var mother_EdYears "Mother's education"	
		lab var father_EdYears "Father's education"
		

		
